///////////////////////////////////////////////////////////////////////////////
//
// Developed by Gardener of Thoughts (gardenerofthoughts.org).
// Released under a "Common Sense License".
//
///////////////////////////////////////////////////////////////////////////////

using System;
using ColorManagement.ColorModels;
using ColorManagement.Conversions;
using Fluogen.Dependz;
using Fluogen.Dependz.Color;
using Fluogen.Dependz.Configuration;

namespace Fluogen.DeployedScripts.ColorExtractors
{
	public class HslLightnessHueForPaletteColorModel : ColorExtractor<DummyScriptConfiguration>
	{
		public override string Description => "RGB( HSL/HCJ/HCL( rc.support, 1, rc.main ) )";

		public override ExtractedColor Extract( IFluonContext fx, IFluonConfiguration fc, IPixelContext px, ColorDeterminant a )
		{
			var colorModel = fc.PaletteOverridingConfiguration.ColorModel.GetValueOrDefault();
			PixelRgbColor color;

			switch( colorModel )
			{
				case ColorModelName.Hsl:
					var hsl = new Hsl( a.Support, 1, a.Main );
					color = PixelRgbColor.FromRgbScalar( HslConverter.ToRgb( hsl ) );
					break;
				case ColorModelName.Hcj: // HCJ colors are very slow.
					var hcj = new Hcj( a.Support, 1, a.Main );
					color = PixelRgbColor.FromRgbScalar( HcjConverter.ToRgb( hcj, DependzConstants.ColorSpace, true ) );
					break;
				case ColorModelName.Hcl: // HCL colors are very slow.
					var hcl = new Hcl( a.Support, 1, a.Main );
					color = PixelRgbColor.FromRgbScalar( HcluvConverter.ToRgb( hcl, DependzConstants.ColorSpace, true ) );
					break;
				default:
					throw new InvalidOperationException( $"Unhandled color model \"{colorModel}\"" );
			}

			return new ExtractedColor( color );
		}
	}
}
