///////////////////////////////////////////////////////////////////////////////
//
// Developed by Gardener of Thoughts (gardenerofthoughts.org).
// Released under a "Common Sense License".
//
///////////////////////////////////////////////////////////////////////////////

using System;
using Fluogen.Dependz;
using Fluogen.Dependz.ColorReducers;
using Fluogen.Dependz.Configuration;
using Got.Libraries;

namespace Fluogen.DeployedScripts.ColorReducers
{
	public class PowAbsAsymptotic : AsymptoticColorReducer<DummyScriptConfiguration>
	{
		public override string Description => "x / (s2 + x); x = rs ^ s1";

		public override void Validate( IFluonConfiguration fc, IColorReducerConfiguration crp )
		{
			base.Validate( fc, crp );

			if( crp.S2 <= 0 )
				throw new ArgumentException( $"{crp.Name}: crp.S2 <= 0" );
		}

		protected override double ReduceAsymptoticallyToUnitary( IFluonContext fx, IFluonConfiguration fc, IColorReducerConfiguration crp
			, double x )
		{
			x = x.PowA( crp.S1 );

			return x / (crp.S2 + x);
		}
	}
}
