///////////////////////////////////////////////////////////////////////////////
//
// Developed by Gardener of Thoughts (gardenerofthoughts.org).
// Released under a "Common Sense License".
//
///////////////////////////////////////////////////////////////////////////////

using System;
using Fluogen.Dependz;
using Fluogen.Dependz.Color;
using Fluogen.Dependz.Configuration;
using Got.Libraries;

namespace Fluogen.DeployedScripts.MdnReducers
{
	public class HarshBoundedEvpEt : MdnReducer<DummyScriptConfiguration>
	{
		public override string Description => "(escaped ? evp : ev) / et";

		public override void Validate( IFluonConfiguration fc )
		{
			base.Validate( fc );

			if( string.IsNullOrEmpty( fc.MdnEscaperName ) )
				throw new ArgumentException( $"{nameof( HarshBoundedEvpEt )}: MdnEscaperName is missing" );

			if( fc.EscapeThreshold.IsZeroWithinEps() )
				throw new ArgumentException( $"{nameof( HarshBoundedEvpEt )}: EscapeThreshold == 0" );
		}

		public override ColorDeterminant Reduce( IFluonContext fx, IFluonConfiguration fc, IPixelContext px, Mdn x, Mdn y, Mdn yp
			, double ev, double evp, ColorDeterminant a, int ri, bool hasEscaped )
		{
			return a.Replace( (hasEscaped ? evp : ev) / fc.EscapeThreshold );
		}
	}
}
