///////////////////////////////////////////////////////////////////////////////
//
// Developed by Gardener of Thoughts (gardenerofthoughts.org).
// Released under a "Common Sense License".
//
///////////////////////////////////////////////////////////////////////////////

using System;
using Fluogen.Dependz;
using Fluogen.Dependz.Configuration;
using Fluogen.DeployedScripts.Libraries;

// #lib PaletteToneExtensions

namespace Fluogen.DeployedScripts.Palettes
{
	public class ForestEnchanted : BitonalGradientPalette<DummyScriptConfiguration>
	{
		protected override IBitonalGradientPaletteConfiguration GetSpecificConfiguration( IFluonConfiguration fc
			, IPaletteContext paletteContext )
		{
			var configuration = base.GetSpecificConfiguration( fc, paletteContext );

			var colorModel = paletteContext.OC.ColorModel.Value;

			if( PX.OC.PaletteVariant != PaletteVariant.Specific )
			{
				configuration.ForestTone1( colorModel, 250, 0 );
				configuration.ViridianTone2( colorModel );
			}

			return configuration;
		}

		protected override IGradientPaletteMarkList GetSpecificVariantMarks( IFluonConfiguration fc )
		{
			var colorModel = PX.OC.ColorModel.Value;

			switch( colorModel )
			{
				case ColorModelName.Hsl:
					return new BitonalGradientPaletteVariant( fc, PX, BGPC
						, new BitonalGradientPaletteToneMarkDatas
							{
								{ 0.0000,  2800, 10000,     0 },
								{ 0.1000,  2800, 10000,   650 },
								{ 0.2167,  2800, 10000,  3050 },
								{ 0.3333,  2800, 10000,  7600 },
								{ 0.4900,  2800, 10000,  9650, true },
								{ 0.6000,   900, 10000,  5200 },
								{ 0.7500,  4000, 10000,  7100 },
								{ 0.8167,  4300,  7700,  5200 },
								{ 0.8833,  4300, 10000,  3200 },
								{ 0.9500,  4300, 10000,  1600 },
								{ 1.0000,  4300, 10000,     0 }
							}
						).ToMarkList();
				default:
					throw new InvalidOperationException( $"Unhandled color model \"{colorModel}\"" );
			}
		}
	}
}
