///////////////////////////////////////////////////////////////////////////////
//
// Developed by Gardener of Thoughts (gardenerofthoughts.org).
// Released under a "Common Sense License".
//
///////////////////////////////////////////////////////////////////////////////

using System;
using Fluogen.Dependz;
using Fluogen.Dependz.Configuration;
using Fluogen.DeployedScripts.Libraries;

// #lib PaletteToneExtensions

namespace Fluogen.DeployedScripts.Palettes
{
	/// <summary>
	/// An intense DragonLava.
	/// </summary>
	public class SeaOfCaramel : BitonalGradientPalette<DummyScriptConfiguration>
	{
		protected override IBitonalGradientPaletteConfiguration GetSpecificConfiguration( IFluonConfiguration fc
			, IPaletteContext paletteContext )
		{
			var configuration = base.GetSpecificConfiguration( fc, paletteContext );

			var colorModel = paletteContext.OC.ColorModel.Value;

			if( PX.OC.PaletteVariant != PaletteVariant.Specific )
			{
				configuration.RubyTone1( colorModel );
				configuration.CaramelTone2( colorModel );
			}

			return configuration;
		}

		protected override IGradientPaletteMarkList GetSpecificVariantMarks( IFluonConfiguration fc )
		{
			var colorModel = PX.OC.ColorModel.Value;

			switch( colorModel )
			{
				case ColorModelName.Hsl:
					return new BitonalGradientPaletteVariant( fc, PX, BGPC
						, new BitonalGradientPaletteToneMarkDatas
							{
								{ 0.0000,   100, 10000,     0 },
								{ 0.1000,   100, 10000,   650 },
								{ 0.2167,   100, 10000,  3050 },
								{ 0.3333,   100, 10000,  7600 },
								{ 0.6000,  1050, 10000, 10000, true },
								{ 0.7500,  1050, 10000,  7100 },
								{ 0.8167,   950, 10000,  5200 },
								{ 0.8833,   850, 10000,  3200 },
								{ 0.9500,   750, 10000,  1600 },
								{ 1.0000,   750, 10000,     0 }
							}
						).ToMarkList();
				default:
					throw new InvalidOperationException( $"Unhandled color model \"{colorModel}\"" );
			}
		}
	}
}
