///////////////////////////////////////////////////////////////////////////////
//
// Developed by Gardener of Thoughts (gardenerofthoughts.org).
// Released under a "Common Sense License".
//
///////////////////////////////////////////////////////////////////////////////

using ColorManagement.ColorModels;
using ColorManagement.Conversions;
using Fluogen.Dependz;
using Fluogen.Dependz.Color;
using Fluogen.Dependz.Configuration;
using Got.Libraries;

namespace Fluogen.DeployedScripts.Palettes
{
	public class TestHsvLightness : Palette<DummyScriptConfiguration>
	{
		public override int FullSize => 1 << 16;
		public override int QuickSize => 256;

		protected int H { get; } = 800;
		protected int S { get; } = 10000;
		protected int V { get; } = 10000;

		protected override void InitializeCache( IFluonConfiguration fc )
		{
		}

		protected override PixelRgbColor ComputeColor( IFluonConfiguration fc, double scalar )
		{
			int toneHue = fc.BitonalGradientPaletteOverridingConfiguration.ToneHue1 != null
				? fc.BitonalGradientPaletteOverridingConfiguration.ToneHue1.Value : H;

			double max = TypeableColorConverter.IntegerMax;
			double h = toneHue / max;
			double s = (1 - scalar) * S / max;
			double v = (scalar < 0.5 ? (2 * scalar).PowA( 0.25 ) : 1) * V / max;

			var hsv = new Hsv( h, s, v );

			var rgb = HsvConverter.ToRgb( hsv );

			var rgb16Bits = Rgb16Bits.FromRgbScalar( rgb );

			return PixelRgbColor.FromRgb16Bits( rgb16Bits.R, rgb16Bits.G, rgb16Bits.B );
		}
	}
}
