///////////////////////////////////////////////////////////////////////////////
//
// Developed by Gardener of Thoughts (gardenerofthoughts.org).
// Released under a "Common Sense License".
//
///////////////////////////////////////////////////////////////////////////////

using System;
using Fluogen.Dependz;
using Fluogen.Dependz.Configuration;
using Fluogen.DeployedScripts.Libraries;

// #lib PaletteToneExtensions

namespace Fluogen.DeployedScripts.Palettes
{
	public class VermilionEdgyWarm : BitonalGradientPalette<DummyScriptConfiguration>
	{
		protected override IBitonalGradientPaletteConfiguration GetSpecificConfiguration( IFluonConfiguration fc
			, IPaletteContext paletteContext )
		{
			var configuration = base.GetSpecificConfiguration( fc, paletteContext );

			var colorModel = paletteContext.OC.ColorModel.Value;

			if( PX.OC.PaletteVariant != PaletteVariant.Specific )
			{
				configuration.EdgesLightness = colorModel.SelectForColorModel( 9400, 9300 );

				configuration.VermilionTone1( colorModel );
				configuration.VermilionTone2( colorModel );

				configuration.TintLightness = colorModel.SelectForColorModel( 6500, 5500 );
			}

			return configuration;
		}

		protected override IGradientPaletteMarkList GetSpecificVariantMarks( IFluonConfiguration fc )
		{
			var colorModel = PX.OC.ColorModel.Value;

			int hue = PaletteToneExtensions.VermilionHueHsl;
			int edgesS = BGPC.OC.EdgesSaturation.GetValueOrDefault( 10000 );
			int edgesL = BGPC.OC.EdgesLightness.GetValueOrDefault( 9400 );
			int tintS = BGPC.OC.TintSaturation.GetValueOrDefault( 10000 );
			int tintL = BGPC.OC.TintLightness.GetValueOrDefault( 6500 );

			switch( colorModel )
			{
				case ColorModelName.Hsl:
					return new BitonalGradientPaletteVariant( fc, PX, BGPC
						, new BitonalGradientPaletteToneMarkDatas
							{
								{ 0.0000, hue, edgesS, edgesL },
								{ 0.0500, hue,  10000,   1200 },
								{ 0.2000, hue,  10000,   3800 },
								{ 0.3500, hue,  10000,   7000 },
								{ 0.4500, hue,  10000,   9500 },
								{ 0.5000, hue,  tintS,  tintL, true },
								{ 0.5500, hue,  10000,   9500 },
								{ 0.6500, hue,  10000,   7000 },
								{ 0.8000, hue,  10000,   3800 },
								{ 0.9500, hue,  10000,   1200 },
								{ 1.0000, hue, edgesS, edgesL }
							}
						).ToMarkList();
				default:
					throw new InvalidOperationException( $"Unhandled color model \"{colorModel}\"" );
			}
		}
	}
}
